All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] emu10k1: change "Music" to "Synth" in mixer control names.
@ 2004-12-29  1:24 Lee Revell
  2004-12-29  2:07 ` Lee Revell
  0 siblings, 1 reply; 5+ messages in thread
From: Lee Revell @ 2004-12-29  1:24 UTC (permalink / raw)
  To: alsa-devel

This patch changes "Music" to "Synth" in the mixer control names, in
order to make it clear that these controls affect the wavetable synth.
"Music" is confusing and could equally well refer to PCM, plus the
Windows drivers (kX and Creative) call it "Synth" so users expect this.

Signed-Off-By: Lee Revell <rlrevell@joe-job.com>

Index: alsa-2.6.10-rc2/alsa-kernel/pci/emu10k1/emufx.c
===================================================================
RCS file: /cvsroot/alsa/alsa-kernel/pci/emu10k1/emufx.c,v
retrieving revision 1.66
diff -u -r1.66 emufx.c
--- alsa-2.6.10-rc2/alsa-kernel/pci/emu10k1/emufx.c	23 Nov 2004 15:11:54 -0000	1.66
+++ alsa-2.6.10-rc2/alsa-kernel/pci/emu10k1/emufx.c	29 Dec 2004 01:20:21 -0000
@@ -1065,10 +1065,10 @@
 	snd_emu10k1_init_stereo_control(&controls[nctl++], "Wave Playback Volume", gpr, 100);
 	gpr += 2;
 
-	/* Music Playback */
+	/* Synth Playback */
 	A_OP(icode, &ptr, iMAC0, A_GPR(stereo_mix+0), A_GPR(stereo_mix+0), A_GPR(gpr), A_FXBUS(FXBUS_MIDI_LEFT));
 	A_OP(icode, &ptr, iMAC0, A_GPR(stereo_mix+1), A_GPR(stereo_mix+1), A_GPR(gpr+1), A_FXBUS(FXBUS_MIDI_RIGHT));
-	snd_emu10k1_init_stereo_control(&controls[nctl++], "Music Playback Volume", gpr, 100);
+	snd_emu10k1_init_stereo_control(&controls[nctl++], "Synth Playback Volume", gpr, 100);
 	gpr += 2;
 
 	/* Wave (PCM) Capture */
@@ -1077,10 +1077,10 @@
 	snd_emu10k1_init_stereo_control(&controls[nctl++], "PCM Capture Volume", gpr, 0);
 	gpr += 2;
 
-	/* Music Capture */
+	/* Synth Capture */
 	A_OP(icode, &ptr, iMAC0, A_GPR(capture+0), A_GPR(capture+0), A_GPR(gpr), A_FXBUS(FXBUS_MIDI_LEFT));
 	A_OP(icode, &ptr, iMAC0, A_GPR(capture+1), A_GPR(capture+1), A_GPR(gpr+1), A_FXBUS(FXBUS_MIDI_RIGHT));
-	snd_emu10k1_init_stereo_control(&controls[nctl++], "Music Capture Volume", gpr, 0);
+	snd_emu10k1_init_stereo_control(&controls[nctl++], "Synth Capture Volume", gpr, 0);
 	gpr += 2;
 
 	/*
@@ -1608,19 +1608,19 @@
 	snd_emu10k1_init_stereo_onoff_control(controls + i++, "Wave Capture Switch", gpr + 2, 0);
 	gpr += 4;
 
 	/* Music Playback Volume */
 	for (z = 0; z < 2; z++)
 		VOLUME_ADD(icode, &ptr, playback + z, 2 + z, gpr + z);
-	snd_emu10k1_init_stereo_control(controls + i++, "Music Playback Volume", gpr, 100);
+	snd_emu10k1_init_stereo_control(controls + i++, "Synth Playback Volume", gpr, 100);
 	gpr += 2;
 
 	/* Music Capture Volume + Switch */
 	for (z = 0; z < 2; z++) {
 		SWITCH(icode, &ptr, tmp + 0, 2 + z, gpr + 2 + z);
 		VOLUME_ADD(icode, &ptr, capture + z, tmp + 0, gpr + z);
 	}
-	snd_emu10k1_init_stereo_control(controls + i++, "Music Capture Volume", gpr, 0);
-	snd_emu10k1_init_stereo_onoff_control(controls + i++, "Music Capture Switch", gpr + 2, 0);
+	snd_emu10k1_init_stereo_control(controls + i++, "Synth Capture Volume", gpr, 0);
+	snd_emu10k1_init_stereo_onoff_control(controls + i++, "Synth Capture Switch", gpr + 2, 0);
 	gpr += 4;
 
 	/* Surround Digital Playback Volume (renamed later without Digital) */




-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now. 
http://productguide.itmanagersjournal.com/

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH] emu10k1: change "Music" to "Synth" in mixer control names.
  2004-12-29  1:24 Lee Revell
@ 2004-12-29  2:07 ` Lee Revell
  0 siblings, 0 replies; 5+ messages in thread
From: Lee Revell @ 2004-12-29  2:07 UTC (permalink / raw)
  To: alsa-devel

On Tue, 2004-12-28 at 20:24 -0500, Lee Revell wrote:
>  	snd_emu10k1_init_stereo_control(&controls[nctl++], "Wave Playback Volume", gpr, 100);
>  	gpr += 2;

I have noticed that many of the PCM controls are assigned names like
"Wave Playback Volume", and later renamed to "PCM Playback Volume" in
the devinit routine.

    476         static char *emu10k1_rename_ctls[] = {
    477                 "Surround Digital Playback Volume", "Surround Playback Volume",
    478                 "Center Digital Playback Volume", "Center Playback Volume",
    479                 "LFE Digital Playback Volume", "LFE Playback Volume",
    480                 NULL    
    481         };

    503         static char *audigy_rename_ctls[] = {
    504                 /* use conventional names */
    505                 "Wave Playback Volume", "PCM Playback Volume",
    506                 /* "Wave Capture Volume", "PCM Capture Volume", */
    507                 "Wave Master Playback Volume", "Master Playback Volume",
    508                 "AMic Playback Volume", "Mic Playback Volume",
    509                 NULL
    510         };

    560         if (emu->audigy)
    561                 c = audigy_rename_ctls; 
    562         else    
    563                 c = emu10k1_rename_ctls;
    564         for (; *c; c += 2)
    565                 rename_ctl(card, c[0], c[1]);


Maybe I am missing something but why not just call it "PCM Playback
Volume" in the first place, and clean up the code a bit?

Lee



-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now. 
http://productguide.itmanagersjournal.com/

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH] emu10k1: change "Music" to "Synth" in mixer control names.
@ 2004-12-29  8:40 Peter Zubaj
  2004-12-29 12:21 ` Takashi Iwai
  0 siblings, 1 reply; 5+ messages in thread
From: Peter Zubaj @ 2004-12-29  8:40 UTC (permalink / raw)
  To: rlrevell; +Cc: alsa-devel

Because these controls are in AC97 too.
You can not have two controls with same name.
First AC97 mixer is created, then DSP mixer is created. Then unneeded
controls from AC97 are removed and DSP controls are renamed to their
final name.

Peter Zubaj

____________________________________
RAMMSTEIN, 22.02.2005 o 20,00, Bratislava Incheba, 
Info: 0904 666 363, http://www.xl.sk 



-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
http://productguide.itmanagersjournal.com/

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH] emu10k1: change "Music" to "Synth" in mixer control names.
  2004-12-29  8:40 [PATCH] emu10k1: change "Music" to "Synth" in mixer control names Peter Zubaj
@ 2004-12-29 12:21 ` Takashi Iwai
  0 siblings, 0 replies; 5+ messages in thread
From: Takashi Iwai @ 2004-12-29 12:21 UTC (permalink / raw)
  To: Peter Zubaj; +Cc: rlrevell, alsa-devel

At Wed, 29 Dec 2004 09:40:57 +0100,
Peter Zubaj wrote:
> 
> Because these controls are in AC97 too.
> You can not have two controls with same name.
> First AC97 mixer is created, then DSP mixer is created. Then unneeded
> controls from AC97 are removed and DSP controls are renamed to their
> final name.

It may be better to simplify the controls.
For example, master volume could be only a digital one and remove the
ac97 master control (always set the max. level) as found in OSS/free
emu10k1 driver.


Takashi


-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now. 
http://productguide.itmanagersjournal.com/

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH] emu10k1: change "Music" to "Synth" in mixer control names.
@ 2004-12-29 12:37 Peter Zubaj
  0 siblings, 0 replies; 5+ messages in thread
From: Peter Zubaj @ 2004-12-29 12:37 UTC (permalink / raw)
  To: tiwai; +Cc: rlrevell, alsa-devel

>It may be better to simplify the controls.
>For example, master volume could be only a digital one and remove the
>ac97 master control (always set the max. level) as found in OSS/free
>emu10k1 driver.

This was done for Audigy (it doesn't use AC97 - only when needed), but
needs to be done for SB Live.

Peter Zubaj

____________________________________
RAMMSTEIN, 22.02.2005 o 20,00, Bratislava Incheba, 
Info: 0904 666 363, http://www.xl.sk 



-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
http://productguide.itmanagersjournal.com/

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2004-12-29 12:37 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2004-12-29  8:40 [PATCH] emu10k1: change "Music" to "Synth" in mixer control names Peter Zubaj
2004-12-29 12:21 ` Takashi Iwai
  -- strict thread matches above, loose matches on Subject: below --
@@ -1608,19 +1608,19 @@
 	gpr += 4;
 
-	/* Music Playback Volume */
+	/* Synth Playback Volume */
 	for (z = 0; z < 2; z++)
 		VOLUME_ADD(icode, &ptr, playback + z, 2 + z, gpr + z);
@@ -1608,19 +1608,19 @@
 	gpr += 2;
 
-	/* Music Capture Volume + Switch */
+	/* Synth Capture Volume + Switch */
 	for (z = 0; z < 2; z++) {
 		SWITCH(icode, &ptr, tmp + 0, 2 + z, gpr + 2 + z);
2004-12-29 12:37 Peter Zubaj
2004-12-29  1:24 Lee Revell
2004-12-29  2:07 ` Lee Revell

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.